@@ -1,6 +1,6 @@
-#' Package download counts and rank percentiles (prototype).
+#' Package download counts and rank percentiles.
 #'
-#' From RStudio's CRAN Mirror http://cran-logs.rstudio.com/
+#' From Posit/RStudio's CRAN Mirror (CDN) http://cran-logs.rstudio.com/
 #' @param packages Character. Vector of package name(s).
 #' @param date Character. Date. "yyyy-mm-dd". NULL uses latest available log.
 #' @param all.filters Logical. Master switch for filters.
@@ -8,81 +8,53 @@
 #' @param small.filter Logical. TRUE filters out downloads less than 1000 bytes.
 #' @param memoization Logical. Use memoization when downloading logs.
 #' @param check.package Logical. Validate and "spell check" package.
+#' @param rank.ties Logical. TRUE uses competition ranking ("1224") for ties. FALSE uses nominal rank (no ties).
 #' @param multi.core Logical or Numeric. \code{TRUE} uses \code{parallel::detectCores()}. \code{FALSE} uses one, single core. You can also specify the number logical cores. Mac and Unix only.
 #' @return An R data frame.
 #' @export
 #' @examples
 #' \dontrun{
-#' packageRank(packages = "HistData", date = "2020-01-01")
+#' packageRank(packages = "cholera", date = "2020-01-01")
 #' packageRank(packages = c("h2o", "Rcpp", "rstan"), date = "2020-01-01")
 #' }
 
-packageRank <- function(packages = "HistData", date = NULL,
+packageRank <- function(packages = "packageRank", date = NULL,
   all.filters = FALSE, ip.filter = FALSE, small.filter = FALSE,
-  memoization = TRUE, check.package = TRUE, multi.core = FALSE) {
-
-  if (!curl::has_internet()) stop("Check internet connection.", call. = FALSE)
-
-  cores <- multiCore(multi.core)
-  if (.Platform$OS.type == "windows" & cores > 1) cores <- 1L
+  memoization = TRUE, check.package = TRUE, rank.ties = TRUE, 
+  multi.core = FALSE) {
 
   if (check.package) packages <- checkPackage(packages)
-  file.url.date <- logDate(date)
-  cran_log <- fetchCranLog(date = file.url.date, memoization = memoization)
-  cran_log <- cleanLog(cran_log)
-  ymd <- rev_fixDate_2012(file.url.date)
-  
-  if (all.filters) {
-    ip.filter <- TRUE
-    small.filter <- TRUE
-  }
 
-  if (small.filter) cran_log <- smallFilter(cran_log)
-  if (ip.filter) cran_log <- ipFilter(cran_log, multi.core = cores)
-  
-  freqtab <- sort(table(cran_log$package), decreasing = TRUE)
+  x <- mcranDistribution(date = date, all.filters = all.filters, 
+    ip.filter = ip.filter, small.filter = small.filter, 
+    memoization = memoization, multi.core = multi.core)
 
-  unobs.pkgs <- !packages %in% cran_log$package
+  unobs.pkgs <- !packages %in% x$data$package
   if (any(unobs.pkgs)) pkg.msg <- paste(packages[unobs.pkgs], collapse = ", ")
 
   if (all(unobs.pkgs)) {
-    stop("No downloads for ", pkg.msg, " on ", ymd, ".", call. = FALSE)
+    stop("No downloads for ", pkg.msg, " on ", x$date, ".", call. = FALSE)
   } else if (any(unobs.pkgs)) {
-    message("No downloads for ", pkg.msg, " on ", ymd, ".")
+    message("No downloads for ", pkg.msg, " on ", x$date, ".")
     packages <- packages[!unobs.pkgs]
   }
-
-  # packages in bin
-  pkg.bin <- lapply(packages, function(nm) freqtab[freqtab %in% freqtab[nm]])
-
-  # offset: ties arbitrarily broken by alphabetical order
-  pkg.bin.delta <- vapply(seq_along(pkg.bin), function(i) {
-    which(names(pkg.bin[[i]]) %in% packages[i])
-  }, numeric(1L))
-
-  nominal.rank <- lapply(seq_along(packages), function(i) {
-    sum(freqtab > freqtab[packages[i]]) + pkg.bin.delta[i]
-  })
-
-  tot.pkgs <- length(freqtab)
-
-  pkg.percentile <- vapply(packages, function(x) {
-    100 * mean(freqtab < freqtab[x])
-  }, numeric(1L))
-
-  dat <- data.frame(date = ymd,
-                    packages = packages,
-                    downloads = c(freqtab[packages]),
-                    rank = unlist(nominal.rank),
-                    percentile = pkg.percentile,
-                    total.downloads = sum(freqtab),
-                    total.packages = tot.pkgs,
-                    stringsAsFactors = FALSE,
-                    row.names = NULL)
-
-  out <- list(packages = packages, date = ymd, package.data = dat,
-    freqtab = freqtab)
-
+  
+  tmp <- x$data[x$data$package %in% packages, ]
+  
+  if (rank.ties) {
+    rnk <- paste(format(tmp$rank, big.mark = ","), "of", 
+                 format(tmp$unique.packages, big.mark = ","))
+  } else {
+    rnk <- paste(format(tmp$nominal.rank, big.mark = ","), "of", 
+                 format(tmp$unique.packages, big.mark = ","))
+  }
+  
+  pkg.data <- data.frame(date = x$date, tmp[, c("package", "count")], 
+    rank = rnk, percentile = tmp$percentile, row.names = NULL)
+  
+  out <- list(packages = packages, date = x$date, package.data = pkg.data, 
+    cran.data = x$data)
+  
   class(out) <- "packageRank"
   out
 }
@@ -103,7 +75,8 @@ packageRank <- function(packages = "HistData", date = NULL,
 plot.packageRank <- function(x, graphics = NULL, log.y = TRUE, ...) {
   if (is.logical(log.y) == FALSE) stop("log.y must be TRUE or FALSE.")
 
-  freqtab <- x$freqtab
+  freqtab <- x$cran.data$count
+  names(freqtab) <- x$cran.data$package
   package.data <- x$package.data
   packages <- x$packages
   date <- x$date
@@ -124,7 +97,9 @@ plot.packageRank <- function(x, graphics = NULL, log.y = TRUE, ...) {
   } else if (graphics == "base") {
     if (length(packages) > 1) {
       invisible(lapply(packages, function(pkg) {
+        grDevices::devAskNewPage(ask = TRUE)
         basePlot(pkg, log.y, freqtab, iqr, package.data, y.max, date)
+        grDevices::devAskNewPage(ask = FALSE)
       }))
     } else {
       basePlot(packages, log.y, freqtab, iqr, package.data, y.max, date)
@@ -210,16 +185,15 @@ ggPlot <- function(x, log.y, freqtab, iqr, package.data, y.max, date) {
 
   if (inherits(date, "Date")) {
     day <- weekdays(as.Date(date), abbreviate = TRUE)
-    id <- paste0(package.data$packages, " @ ", date, " (", day, ")")
+    id <- paste0(package.data$package, " @ ", date, " (", day, ")")
   } else {
-    id <- paste0(package.data$packages, " @ ", date)
+    id <- paste0(package.data$packags, " @ ", date)
   }
 
   download.data <- data.frame(x = seq_along(freqtab),
-                              y = c(freqtab),
+                              y = freqtab,
                               packages = names(freqtab),
-                              row.names = NULL,
-                              stringsAsFactors = FALSE)
+                              row.names = NULL)
 
   download.lst <- rep(list(download.data), length(x$packages))
 
@@ -264,7 +238,7 @@ ggPlot <- function(x, log.y, freqtab, iqr, package.data, y.max, date) {
          ggplot2::aes(x = .data$x, y = .data$y)) +
        ggplot2::geom_line() +
        ggplot2::geom_vline(xintercept = iqr, colour = "gray", 
-        linetype = "dotted") +
+         linetype = "dotted") +
        ggplot2::geom_point(data = download.data[first, ],
                            shape = 1,
                            colour = "dodgerblue") +
@@ -278,7 +252,7 @@ ggPlot <- function(x, log.y, freqtab, iqr, package.data, y.max, date) {
                           label = tot.dwnld,
                           hjust = 1,
                           size = 3) +
-       ggplot2::geom_text(data = iqr.data, label = iqr.data$label) +
+       ggplot2::geom_text(data = iqr.data, label = iqr.data$label, size = 3.5) +
        ggplot2::geom_vline(data = point.data,
          ggplot2::aes(xintercept = .data$x), colour = alpha.col) +
        ggplot2::geom_hline(data = point.data, 
@@ -288,7 +262,8 @@ ggPlot <- function(x, log.y, freqtab, iqr, package.data, y.max, date) {
            size = 2) +
        ggplot2::geom_label(data = point.data, 
          ggplot2::aes(x = .data$x, y = .data$y), fill = alpha.col, 
-           colour = "white", size = label.size, label = ylabel, nudge_x = 2000) +
+           colour = "white", size = label.size, label = ylabel,
+           nudge_x = 2000) +
        ggplot2::geom_label(data = point.data, 
           ggplot2::aes(x = .data$x, y = .data$y), fill = alpha.col, 
             colour = "white", size = label.size, label = xlabel, 
@@ -309,14 +284,7 @@ ggPlot <- function(x, log.y, freqtab, iqr, package.data, y.max, date) {
 #' @export
 
 print.packageRank <- function(x, ...) {
-  dat <- x$package.data
-  dat$downloads <- format(dat$downloads, big.mark = ",")
-  rank <- paste(format(dat$rank, big.mark = ","), "of",
-                format(dat$total.packages, big.mark = ","))
-  out <- data.frame(dat[, c("date", "packages", "downloads")], rank,
-    percentile = round(dat[, "percentile"], 1), stringsAsFactors = FALSE,
-    row.names = NULL)
-  print(out)
+  print(x$package.data)
 }
 
 #' Summary method for packageRank().
